@@ -114,7 +114,7 @@ Dstream::Dstream(ostream *r, const char * cfg_nm )
     Text_db cfg(fn);
     while (! cfg.eof()){	     
 	 Text_record  r(  cfg++);
-	 if (r.sz() != 2) {
+	 if (r.size() != 2) {
 	     r.message("not enough fields in Dstream init.");
 	     continue;
 	 }
